﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="html" indent="yes" version="4.01"
    doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
    doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>
  <xsl:param name="CSSFile1"></xsl:param>
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml">
      <xsl:choose>
        <xsl:when test="//Settings/ForeignGroupMode=1">
          <xsl:attribute name="lang">
            <xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
          </xsl:attribute>
          <xsl:attribute name="dir">
            <xsl:value-of select="//Settings/ForeignGroupDirection"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="lang">
            <xsl:value-of select="//Settings/LanguageCode"/>
          </xsl:attribute>
          <xsl:attribute name="dir">
            <xsl:value-of select="//Settings/Direction"/>
          </xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <head>
	    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
        <meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
        <xsl:choose>
          <xsl:when test="$CSSFile1 !=''">
            <style type="text/css">
              <xsl:value-of select="$CSSFile1"/>
            </style>
          </xsl:when>
          <xsl:otherwise>
            <link rel="stylesheet" type="text/css" href="Workbook-S-140-PublicTalk-WatchtowerStudy-ServiceTalk-Version2.css"/>
          </xsl:otherwise>
        </xsl:choose>
        <title>
          <xsl:value-of select="//Labels/Congregation"/>&#160;<xsl:value-of select="//Labels/Title" />
        </title>
      </head>
      <body>
        <div class="containerPage">
          <xsl:for-each select="MeetingWorkBook/Meeting">
            <div class="containerMeeting">
              <xsl:if test="@PageBreak=1">
                <xsl:attribute name="style">page-break-before: always</xsl:attribute>
              </xsl:if>
              <xsl:if test="@PageBreak=1 or position()=1">
                <xsl:call-template name="HEADING"/>
              </xsl:if>
              <xsl:if test="@BookmarkId">
                <a>
                  <xsl:attribute name="name">
                    <xsl:value-of select="concat('week', @BookmarkId)"/>
                  </xsl:attribute>
                  <![CDATA[ ]]>
                </a>
              </xsl:if>

              <!-- The WEEK template will conditionally display any Special Event (if appropriate) -->
              <xsl:call-template name="WEEK"/>

              <!-- The TFGW | AYFM | LAC elements only exist if there is a valid Midweek Meeting. -->
              <xsl:apply-templates select="TFGW"/>
              <xsl:apply-templates select="AYFM"/>
              <xsl:apply-templates select="LAC"/>
              
              <!-- We add our hr element here (between the two tables) -->
              <hr class="gap-with-line"/>

              <!-- PUBLICTALK element only exists if there is a valid Weekend Meeting. -->
              <xsl:apply-templates select="PUBLICTALK"/>

              <!-- We need to detect if there is a Memorial at the Weekend. -->
              <xsl:call-template name="MEMORIAL-WEEKEND"/>

            </div>
          </xsl:for-each>
        </div>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="WEEK">
    <table class="tableDATE" cellspacing="0" cellpadding="0">
      <xsl:call-template name="SetColumnWidths"/>
      <xsl:if test="@SpecialEvent=1 and @CircuitVisit=0 and (SpecialEvent/Date/@MidweekEvent=1 or SpecialEvent/Date/@Memorial=0)">
        <tr>
          <td class="cellBibleReading" colspan="4">
            <xsl:value-of select="Date"/>
            <xsl:if test="WeeklyBibleReading != ''">
              <xsl:text> | </xsl:text>
              <xsl:value-of select="WeeklyBibleReading"/>
            </xsl:if>
          </td>
        </tr>
        <xsl:apply-templates select="SpecialEvent"/>
      </xsl:if>
      <!-- We can include the meeting if the special event is the Memorial (held at the Weekend) -->
      <xsl:if test="@SpecialEvent=0 or (@SpecialEvent=1 and SpecialEvent/Date/@MidweekEvent=0 and SpecialEvent/Date/@Memorial=1) or @CircuitVisit=1">
        <tr>
          <td class="cellBibleReading" colspan="3">
            <div class="floatRight">
              <xsl:value-of select="//Labels/Chairman"/>
              <xsl:if test="@NumberClasses = 2">
                <br/>
                <xsl:value-of select="//Labels/AuxCounsellor"/>
              </xsl:if>
              <xsl:if test="@NumberClasses = 3">
                <br/>
                <xsl:value-of select="//Labels/AuxCounsellor1"/>
                <br/>
                <xsl:value-of select="//Labels/AuxCounsellor2"/>
              </xsl:if>
            </div>
            <div class="textMidweekHeading">
              <xsl:text>Likita ya kati ya pɔsɔ</xsl:text>
            </div>
          </td>
          <td class="cellName">
            <xsl:choose>
              <xsl:when test="Chairman/@Duplicate=1">
                <span class="textDuplicate">
                  <xsl:value-of select="Chairman"/>&#160;
                </span>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="Chairman"/>&#160;
              </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="@NumberClasses &gt;= 2">
              <br/>
              <xsl:choose>
                <xsl:when test="AuxCounsellor1/@Duplicate=1">
                  <span class="textDuplicate">
                    <xsl:value-of select="AuxCounsellor1"/>&#160;
                  </span>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="AuxCounsellor1"/>&#160;
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
            <xsl:if test="@NumberClasses = 3">
              <br/>
              <xsl:choose>
                <xsl:when test="AuxCounsellor2/@Duplicate=1">
                  <span class="textDuplicate">
                    <xsl:value-of select="AuxCounsellor2"/>&#160;
                  </span>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="AuxCounsellor2"/>&#160;
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </td>
        </tr>
        <xsl:call-template name="MidweekVideoConferenceInfo"/>
        <xsl:apply-templates select="Note"/>
        <tr>
          <td colspan="4">&#160;</td>
        </tr>
        <tr>
          <xsl:apply-templates select="SongOpen" />
          <xsl:apply-templates select="PrayerOpen" />
        </tr>
        <xsl:apply-templates select="OpeningComments" />
      </xsl:if>
    </table>
  </xsl:template>
  
  <xsl:template name="MidweekVideoConferenceInfo">
    <xsl:if test="VideoConferenceHost != '' and VideoConferenceCohost != ''">
      <tr>
        <td colspan="3">
          <div class="floatRight">
            <xsl:value-of select="//Labels/VideoConferenceHost"/>
            <br/>
            <xsl:value-of select="//Labels/VideoConferenceCohost"/>
          </div>
        </td>
        <td class="cellName">
          <xsl:apply-templates select="VideoConferenceHost"/>
          <br/>
          <xsl:apply-templates select="VideoConferenceCohost"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <xsl:template name="WeekendVideoConferenceInfo">
    <xsl:if test="Assignments/VideoConferenceHost != '' and Assignments/VideoConferenceCohost != ''">
      <tr>
        <td class ="cellWEEKEND" colspan="2">
          <div class="floatRight">
            <xsl:value-of select="//Labels/VideoConferenceHost"/>
            <br/>
            <xsl:value-of select="//Labels/VideoConferenceCohost"/>
          </div>
        </td>
        <td class="cellName">
          <xsl:apply-templates select="Assignments/VideoConferenceHost"/>
          <br/>
          <xsl:apply-templates select="Assignments/VideoConferenceCohost"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <xsl:template name="MEMORIAL-WEEKEND">
    <!-- 1. Is there a Special Event associated with this week? -->
    <!-- 2. Is it the Memorial? -->
    <!-- 3. Is the Memorial at the Weekend? -->
    <!-- If the answers are all Yes then we must display the Special Event information. -->
    <xsl:if test="@SpecialEvent=1 and SpecialEvent/Date/@Memorial=1 and SpecialEvent/Date/@MidweekEvent=0">
      <table class="tableWeekend">
        <tr>
          <!-- We need to use a colspan of 4 for consitency with the logic of the SpecialEvent template. -->
          <td class ="cellWEEKEND" colspan="4">
            <div class="textWEEKEND" style="float:left">
              <xsl:value-of select="//Labels/PTS_WeekendMeeting"/>
            </div>
          </td>
        </tr>
        <xsl:apply-templates select="SpecialEvent"/>
      </table>
    </xsl:if>
  </xsl:template>

  <!--Displays the notes (if any)-->
  <xsl:template match="Note">
    <xsl:if test="normalize-space(.) != ''">
      <tr>
        <td class="cellNotes" colspan="4">
          <xsl:value-of select="//Labels/Note"/>:&#160;<xsl:value-of select="."/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <xsl:template match="SpecialEvent">
    <tr>
      <td class="textSpecialEvent" colspan="4">
        <xsl:value-of select="Event"/>
        <xsl:text> [</xsl:text>
        <xsl:value-of select="Date"/>
        <xsl:text>]</xsl:text>
      </td>
    </tr>
    <xsl:if test="normalize-space(Location) != ''">
      <tr>
        <td class="textSpecialEventLocation" colspan="4">
          <xsl:value-of select="Location"/>
        </td>
      </tr>
    </xsl:if>
  </xsl:template>

  <!--Displays heading with a nice double underline-->
  <xsl:template name="HEADING">
    <div class="borderHEADINGOuter">
      <div class="borderHEADINGInner">
        <table class="tableHEADING">
          <tr>
            <td class="textCongregation">
              <xsl:value-of select="//Labels/Congregation"/>
            </td>
            <td class="textTitle">
              <xsl:text>Programɛ ya makita ya lisangá - </xsl:text>
              <xsl:variable name="SD" select="substring(Date/@ThisWeek, 8, 2)"/>
              <xsl:variable name="SM" select="substring(Date/@ThisWeek, 6, 2)"/>
              <xsl:value-of select="format-number($SD, '0')"/>
              <xsl:text>/</xsl:text>
              <xsl:value-of select="$SM"/>
              <xsl:text>-</xsl:text>
              <xsl:call-template name="add-days-to-date">
                <xsl:with-param name="days-to-add" select="6"/>
              </xsl:call-template>
            </td>
          </tr>
        </table>
      </div>
    </div>
  </xsl:template>

  <xsl:template name="add-days-to-date">
    <xsl:param name="days-to-add"/>
    <xsl:param name="year" select="substring(Date/@ThisWeek, 2, 4)"/>
    <xsl:param name="month" select="substring(Date/@ThisWeek, 6, 2)"/>
    <xsl:param name="day" select="substring(Date/@ThisWeek, 8, 2)"/>
    <xsl:param name="a" select="floor((14 - $month) div 12)"/>
    <xsl:param name="y" select="$year + 4800 - $a"/>
    <xsl:param name="m" select="$month + 12*$a - 3"/>
    <xsl:param name="JDN" select="$day + floor((153*$m + 2) div 5) + 365*$y + floor($y div 4) - floor($y div 100) + floor($y div 400) - 32045 + $days-to-add" />
    <xsl:param name="f" select="$JDN + 1401 + floor((floor((4 * $JDN + 274277) div 146097) * 3) div 4) - 38"/>
    <xsl:param name="e" select="4*$f + 3"/>
    <xsl:param name="g" select="floor(($e mod 1461) div 4)"/>
    <xsl:param name="h" select="5*$g + 2"/>
    <xsl:param name="D" select="floor(($h mod 153) div 5 ) + 1"/>
    <xsl:param name="M" select="(floor($h div 153) + 2) mod 12 + 1"/>
    <xsl:param name="Y" select="floor($e div 1461) - 4716 + floor((14 - $M) div 12)"/>
    <xsl:param name="MM" select="format-number($M, '00')"/>
    <xsl:param name="DD" select="format-number($D, '0')"/>
    <xsl:value-of select="concat($DD, '/', $MM)" />
  </xsl:template>

  <!--Display the end time (using 24 hour format)-->
  <xsl:template match="Time" mode="End">
    <td class="cellTime">
      <xsl:value-of select="@EndTime24"/>
    </td>
  </xsl:template>

  <!--Display the start time (using 24 hour format)-->
  <xsl:template match="Time" mode="Start">
    <td class="cellTime">
      <xsl:value-of select="@StartTime24"/>
    </td>
  </xsl:template>

  <!--Displays the duration of the item in minutes-->
  <xsl:template match="Time" mode="Duration">
    <span class="textDuration">
      (<xsl:value-of select="."/>)
    </span>
  </xsl:template>

  <!--Display the name of the brother assigned-->
  <xsl:template match="Name | PrayerOpen | PrayerEnd">
    <td class="cellName">
      <xsl:choose>
        <xsl:when test="@Duplicate=1">
          <span class="textDuplicate">
            <xsl:value-of select="."/>
          </span>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>
  
  <!-- Display the Host / Co-Host -->
  <xsl:template match="VideoConferenceHost | VideoConferenceCohost">
    <xsl:param name="NameToHighlight"/>
    <xsl:choose>
      <xsl:when test="@Duplicate=1">
        <span class="textDuplicate">
          <xsl:value-of select="."/>
        </span>
      </xsl:when>
      <xsl:when test=".=$NameToHighlight">
        <span class="textHighlight">
          <xsl:value-of select="."/>&#160;
        </span>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>  

  <!--Displays the theme for the assignment-->
  <xsl:template match="Theme">
    <span class="textTheme">
      <xsl:value-of select="." disable-output-escaping="yes"/>
    </span>
  </xsl:template>

  <!--Displays the chairman label-->
  <xsl:template name="Chairman">
    <td class="cellName">
      <!--Trims the " :" from the end of the chairman label-->
      <xsl:value-of select="normalize-space(translate(//Labels/Chairman,':',''))"/>
    </td>
  </xsl:template>

  <xsl:template match="Method">
    <span class="textMethod">
      <xsl:value-of select="." disable-output-escaping="yes"/>
    </span>
  </xsl:template>

  <!--Treasures From God's Word-->
  <xsl:template match="TFGW">
    <table class="tableTFGW" cellspacing="0" cellpadding="0">
      <xsl:call-template name="SetColumnWidths"/>

      <xsl:call-template name="SectionHeading">
        <xsl:with-param name="strSection">TFGW</xsl:with-param>
        <xsl:with-param name="iSpanColumns">3</xsl:with-param>
      </xsl:call-template>

      <xsl:apply-templates select="TFGWItem">
        <xsl:with-param name="iSpanCols">
          <xsl:value-of select="@NumberClasses"/>
        </xsl:with-param>
      </xsl:apply-templates>
      <xsl:apply-templates select="BibleReadingItem"/>
    </table>
  </xsl:template>

  <!--Bible talk and Digging for Spiritual Gems-->
  <xsl:template match="TFGWItem">
    <xsl:param name="iSpanCols"/>
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td colspan="{$iSpanCols+1}">
        <span class="bulletTFGW">&#8226;</span>
        <xsl:apply-templates select="Theme"/>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:apply-templates select="Method"/>
      </td>
      <xsl:apply-templates select="Name"/>
    </tr>
  </xsl:template>

  <!--Displays all of the bible reading students for each class-->
  <xsl:template match="BibleReadingItem">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme">
        <span class="bulletTFGW">&#8226;</span>
        <span class="textTheme">
          <xsl:value-of select="Type"/>
        </span>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:apply-templates select="Material"/>
      </td>
      <td class="cellPosition">
        <xsl:value-of select="//Labels/Student"/>
      </td>
      <xsl:for-each select="Readers/Reader">
        <td class="cellName">
          <xsl:choose>
            <xsl:when test="@Duplicate=1">
              <span class="textDuplicate">
                <xsl:value-of select="."/>
              </span>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="."/>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </xsl:for-each>
    </tr>
  </xsl:template>

  <!-- Display the study number reference -->
  <xsl:template match="@StudyPointReference">
    <span class="textStudyNumberReference">
      <xsl:text> </xsl:text>
      <xsl:value-of select="."/>
    </span>
  </xsl:template>

  <!--Apply Yourself To The Field Ministry-->
  <xsl:template match="AYFM">
    <table class="tableAYFM" cellspacing="0" cellpadding="0">
      <xsl:call-template name="SetColumnWidths"/>

      <xsl:call-template name="SectionHeading">
        <xsl:with-param name="strSection">AYFM</xsl:with-param>
        <xsl:with-param name="iSpanColumns">3</xsl:with-param>
      </xsl:call-template>

      <xsl:apply-templates select="Teaching" />
      <xsl:apply-templates select="StudentItem"/>
    </table>
  </xsl:template>

  <!-- Teaching assigning - 10 minute talk on the first week of the month -->
  <xsl:template match="Teaching">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme" colspan="2">
        <span class="bulletAYFM">&#8226;</span>
        <span class="textTheme">
          <xsl:value-of select="Type"/>
        </span>
        <xsl:apply-templates select="Theme"/>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:apply-templates select="StudyPointDescription"/>
      </td>

      <!-- There is only ONE "Name" element, so we need to factor in for the two extra classes-->
      <xsl:apply-templates select="Name"/>
      <xsl:if test = "../@NumberClasses &gt;= 2">
        <!-- Include the "Name" element again -->
        <xsl:apply-templates select="Name"/>
      </xsl:if>

      <xsl:if test = "../@NumberClasses &gt;= 3">
        <!-- Include the "Name" element again -->
        <xsl:apply-templates select="Name"/>
      </xsl:if>
    </tr>
  </xsl:template>

  <!--Displays all the information for a student item.
  This includes all the students from each class.-->
  <xsl:template match="StudentItem">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme">
        <span class="bulletAYFM">&#8226;</span>
        <span class="textTheme">
          <xsl:value-of select="Type"/>
        </span>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:choose>
          <xsl:when test="@IsSampleVideo=1">
            <xsl:apply-templates select="Material" mode="NoStudyPoint"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="Material"/>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <td class="cellPosition">
        <xsl:choose>
          <xsl:when test="@IsSampleVideo=1">
            <!--We need an empty cell-->
            <xsl:text> </xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="//Labels/Student"/>
            <xsl:if test="@IsTalk=0">
              <br/>
              <xsl:value-of select="//Labels/Assistant"/>
            </xsl:if>
          </xsl:otherwise>
        </xsl:choose>
      </td>
      <xsl:apply-templates select="Students"/>
    </tr>
  </xsl:template>

  <xsl:template match="Material | SourceMaterial | StudyPointDescription">
    <span class="textMaterial">
      <xsl:value-of select="." disable-output-escaping="yes"/>
      <!-- Display the study point in brackets (if it exists) -->
      <xsl:apply-templates select="@StudyPointReference"/>
    </span>
  </xsl:template>

  <xsl:template match="Material" mode="NoStudyPoint">
    <span class="textMaterial">
      <xsl:value-of select="." disable-output-escaping="yes"/>
    </span>
  </xsl:template>

  <!--Displays the student and assistant for the current student item-->
  <xsl:template match="Students">
    <td class="cellName">
      <xsl:choose>
        <xsl:when test="../@IsSampleVideo=1">
          <xsl:choose>
            <xsl:when test="@ChairmanHandleSampleVideo=0">
              <xsl:value-of select="//Labels/Counsellor"/>
            </xsl:when>
            <xsl:otherwise>
              <!--Trims the " :" from the end of the chairman label-->
              <xsl:value-of select="normalize-space(translate(//Labels/Chairman,':',''))"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <xsl:choose>
            <xsl:when test="Student/@Duplicate=1">
              <span class="textDuplicate">
                <xsl:value-of select="Student"/>
              </span>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="Student"/>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:if test="../@IsTalk=0">
            <br/>
            <xsl:choose>
              <xsl:when test="Assistant/@Duplicate=1">
                <span class="textDuplicate">
                  <xsl:value-of select="Assistant"/>
                </span>
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="Assistant"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </xsl:template>

  <!--Define the column widths for the schedule-->
  <xsl:template name="SetColumnWidths">
    <!--The widths in the column classes will add up to 100%-->
    <xsl:choose>
      <xsl:when test="not(@NumberClasses) or @NumberClasses=1 or self::Meeting">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme1Class"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
      <xsl:when test="@NumberClasses=2">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme2Class"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
      <xsl:when test="@NumberClasses=3">
        <colgroup>
          <col class="columnTime"/>
          <col class="columnTheme3Class"/>
          <col class="columnPosition"/>
          <col class="columnName"/>
          <col class="columnName"/>
          <col class="columnName"/>
        </colgroup>
      </xsl:when>
    </xsl:choose>
  </xsl:template>

  <!--Living As Christians-->
  <xsl:template match="LAC">
    <table class="tableLAC" cellspacing="0" cellpadding="0">
      <xsl:call-template name="SetColumnWidths"/>

      <xsl:call-template name="SectionHeading">
        <xsl:with-param name="strSection">LAC</xsl:with-param>
        <xsl:with-param name="iSpanColumns">4</xsl:with-param>
      </xsl:call-template>

      <tr>
        <xsl:apply-templates select="SongMiddle" />
      </tr>
      <xsl:apply-templates select="LACItem" />

      <xsl:choose>
        <xsl:when test="@CircuitVisit=0">
          <xsl:apply-templates select="CongregationBibleStudy" />
          <xsl:apply-templates select="ClosingComments"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:apply-templates select="ClosingComments"/>
          <xsl:apply-templates select="CircuitVisit/LACItem"/>
        </xsl:otherwise>
      </xsl:choose>

      <tr>
        <xsl:apply-templates select="SongEnd"/>
        <xsl:apply-templates select="PrayerEnd" />
      </tr>
    </table>
  </xsl:template>

  <xsl:template name="SectionHeading">
    <xsl:param name="strSection"/>
    <xsl:param name="iSpanColumns"/>
    <tr>
      <td class="cell{$strSection}" colspan="{$iSpanColumns}">
        <div class="text{$strSection}">
          <xsl:value-of select="//Labels/*[name() = $strSection]"/>
        </div>
      </td>
      <xsl:if test="@NumberClasses = 3">
        <td class="cellClass">
          <xsl:value-of select="//Labels/AuxClass1"/>
        </td>
        <td class="cellClass">
          <xsl:value-of select="//Labels/AuxClass2"/>
        </td>
      </xsl:if>
      <xsl:if test="@NumberClasses = 2">
        <td class="cellClass">
          <xsl:value-of select="//Labels/AuxClass"/>
        </td>
      </xsl:if>
      <xsl:if test="@NumberClasses &gt;= 1">
        <td class="cellClass">
          <xsl:value-of select ="//Labels/MainHall"/>
        </td>
      </xsl:if>
    </tr>
  </xsl:template>

  <!--Living As Christians - Item-->
  <xsl:template match="LACItem">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme" colspan="2">
        <span class="bulletLAC">&#8226;</span>
        <xsl:apply-templates select="Theme"/>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:apply-templates select="Method"/>
      </td>
      <xsl:apply-templates select="Name"/>
    </tr>
  </xsl:template>

  <!--Displays the Congregation Bible Study information-->
  <xsl:template match="CongregationBibleStudy">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme">
        <span class="bulletLAC">&#8226;</span>
        <span class="textTheme">
          <xsl:value-of select="//Labels/CBS"/>
        </span>
        <xsl:apply-templates select="Time" mode="Duration"/>
        <xsl:apply-templates select="SourceMaterial" />
      </td>
      <td class="cellPosition">
        <xsl:value-of select="//Labels/Conductor"/>
        <br/>
        <xsl:value-of select="//Labels/Reader"/>
      </td>
      <td class="cellName">
        <xsl:choose>
          <xsl:when test="Conductor/@Duplicate=1">
            <span class="textDuplicate">
              <xsl:value-of select="Conductor"/>
            </span>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="Conductor"/>
          </xsl:otherwise>
        </xsl:choose>
        <br/>
        <xsl:choose>
          <xsl:when test="Reader/@Duplicate=1">
            <span class="textDuplicate">
              <xsl:value-of select="Reader"/>
            </span>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="Reader"/>
          </xsl:otherwise>
        </xsl:choose>
      </td>
    </tr>
  </xsl:template>

  <!--Displays the song information-->
  <xsl:template match="SongOpen | SongMiddle | SongEnd">
    <td class="cellTime">
      <xsl:value-of select="@EndTime24"/>
    </td>
    <td class="cellTheme">
      <xsl:if test="self::SongMiddle">
        <xsl:attribute name="colspan">3</xsl:attribute>
        <xsl:attribute name="class"></xsl:attribute>
      </xsl:if>
      <span>
        <xsl:attribute name="class">
          <xsl:choose>
            <xsl:when test="self::SongOpen">bulletTFGW</xsl:when>
            <xsl:otherwise>bulletLAC</xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        <xsl:text>&#8226;</xsl:text>
      </span>
      <span class="textSongLabel">
        <xsl:value-of select="//Labels/Song"/>
      </span>
      <span class="textSongNumber">
        <xsl:value-of select="."/>
      </span>
      <span class="textSongTitle">
        <xsl:value-of select="@Title"/>
      </span>
    </td>
    <xsl:if test="self::SongOpen or self::SongEnd">
      <td class="cellPosition">
        <xsl:value-of select="//Labels/Prayer"/>
      </td>
    </xsl:if>
  </xsl:template>

  <!--Displays the comments-->
  <xsl:template name="Comments">
    <xsl:param name="bulletClass" />
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellTheme" colspan="2">
        <span class="{ $bulletClass }">&#8226;</span>
        <xsl:apply-templates select="Theme"/>
        <xsl:apply-templates select="Time" mode="Duration"/>
      </td>
      <xsl:call-template name="Chairman"/>
    </tr>
  </xsl:template>

  <xsl:template match="OpeningComments">
    <xsl:call-template name="Comments">
      <xsl:with-param name="bulletClass">bulletTFGW</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="ClosingComments">
    <xsl:call-template name="Comments">
      <xsl:with-param name="bulletClass">bulletLAC</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="PUBLICTALK">
    <table class="tableWeekend">
      <colgroup>
        <col class ="columnTime"/>
        <col class ="columnPublicTalk"/>
        <col class ="columnName"/>
      </colgroup>
      <tr>
        <td class ="cellWEEKEND" colspan="2">
          <div class="textWEEKEND" style="float:left">
            <xsl:value-of select="//Labels/PTS_WeekendMeeting"/>
          </div>
          <div class="floatRight">
            <xsl:value-of select="//Labels/PTS_Chairman"/>:
          </div>
        </td>
        <td class="cellName">
          <xsl:value-of select="Assignments/Chairman"/>
        </td>
      </tr>
      <xsl:call-template name="WeekendVideoConferenceInfo"/>
      <xsl:apply-templates select="HomeTalk"/>
      <xsl:apply-templates select="AwayTalk"/>
      <xsl:apply-templates select="Assignments"/>
    </table>
  </xsl:template>

  <!--Displays the Home Talk Speaker details-->
  <xsl:template match="HomeTalk">
    <tr>
      <xsl:apply-templates select="Time" mode="End"/>
      <td class="cellWEEKENDText">
        <div class="floatRight">
          <xsl:value-of select="//Labels/PTS_Congregation"/>:
        </div>
        <span class="textPTSLabel">
          <xsl:value-of select="//Labels/PTS_Speaker"/>:
        </span>
        <xsl:text> </xsl:text>
        <span class="textPTSValue">
          <xsl:value-of select="Speaker"/>
        </span>
      </td>
      <td class="cellName">
        <xsl:value-of select="Congregation"/>
      </td>
    </tr>
    <tr>
      <td class="cellWEEKENDText" colspan="3">
        <span class="textPTSLabel">
          <xsl:value-of select="//Labels/PTS_Theme"/>:
        </span>
        <xsl:text> </xsl:text>
        <span class="textPTSValue">
          <xsl:value-of select="Theme"/>
        </span>
      </td>
    </tr>
  </xsl:template>

  <!--Displays the Away Talk Speaker and Congregation-->
  <xsl:template match="AwayTalk">
    <tr>
      <td class="cellWEEKENDText" colspan="3">
        <span class="textPTSLabel">
          <xsl:choose>
            <!--We only support 2 Away Speakers. We could just use one label-->
            <xsl:when test="position()=1">
              <xsl:value-of select="//Labels/PTS_AwaySpeaker1"/>:
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="//Labels/PTS_AwaySpeaker2"/>:
            </xsl:otherwise>
          </xsl:choose>
        </span>
        <xsl:text> </xsl:text>
        <span class="textPTSValue">
          <xsl:value-of select="Speaker"/>
          <xsl:text> (</xsl:text>
          <xsl:value-of select="Congregation"/>
          <xsl:text>)</xsl:text>
        </span>
      </td>
    </tr>
  </xsl:template>

  <!--Displays the Watchtower Study, Conductor and Reader-->
  <xsl:template match="Assignments">
    <!--Heading-->
    <tr>
      <td style="padding-left: 1mm;" colspan="3">
        <div class="WTHeading">
          <xsl:value-of select="//Labels/PTS_WTStudy"/>
        </div>
      </td>
    </tr>
    <!--Watchtower Study Theme and Conductor-->
    <tr>
      <xsl:apply-templates select="WatchtowerStudy/Time" mode="End"/>
      <td class="cellWEEKENDText">
        <span class="textPTSValue">
          <div class="floatRight">
            <xsl:value-of select="//Labels/PTS_WTConductor"/>:
          </div>
          <xsl:value-of select="WatchtowerStudy/Theme"/>
        </span>
      </td>
      <td class="cellName">
        <xsl:value-of select="Conductor"/>
      </td>
    </tr>
    <xsl:choose>
      <!--This is not a Circuit Visit so show the Reader-->
      <xsl:when test="../../@CircuitVisit=0">
        <tr>
          <td class="cellWEEKENDText" colspan="2">
            <div class="floatRight">
              <xsl:value-of select="//Labels/PTS_WTReader"/>:
            </div>
          </td>
          <td class="cellName">
            <xsl:value-of select="Reader"/>
          </td>
        </tr>
      </xsl:when>
      <!--This is a Circuit Visit so show the final Service Talk-->
      <xsl:otherwise>
        <tr>
          <td style="padding-left: 1mm;" colspan="3">
            <div class="ServiceTalkHeading">
              <xsl:value-of select="//Labels/PTS_ServiceTalk"/>
            </div>
          </td>
        </tr>
        <tr>
          <xsl:apply-templates select="ServiceTalk/Time" mode="End"/>
          <td class="cellWEEKENDText">
            <span class="textPTSLabel">
              <xsl:value-of select="//Labels/PTS_Theme"/>:
            </span>
            <xsl:text> </xsl:text>
            <span class="textPTSValue">
              <xsl:value-of select="ServiceTalk/Theme"/>
            </span>
          </td>
          <td class="cellName">
            <xsl:value-of select="../preceding-sibling::*[1]/CircuitVisit/LACItem/Name"/>
          </td>
        </tr>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>